# order of conns is not stable, let's just check if we have our 6 tunnels
ipsec trafficstatus | wc -l
../../guestbin/ipsec-kernel-state.sh
../../guestbin/ipsec-kernel-policy.sh
